@@ -1,5 +1,6 @@
 # from __future__ import print_function, absolute_import, division
 import copy
+import logging
 import multiprocessing
 import shutil
 import types
@@ -13,6 +14,7 @@ import matplotlib.pyplot as plt
 import matplotlib.gridspec as gridspec
 import yaml
 from astropy.time import Time
+from lcbuilder.lcbuilder_class import LcBuilder
 from lightkurve import TessLightCurve
 from matplotlib.colorbar import Colorbar
 from matplotlib import patches
@@ -46,6 +48,7 @@ from triceratops.likelihoods import (simulate_TP_transit, simulate_EB_transit)
 from triceratops.funcs import (Gauss2D, query_TRILEGAL, renorm_flux, stellar_relations)
 from astropy import constants
 import uuid
+from sherlockpipe.eleanor import maxsector
 
 '''WATSON: Verboseless Vetting and Adjustments of Transits for Sherlock Objects of iNterest
 This class intends to provide a inspection and transit fitting tool for SHERLOCK Candidates.
@@ -87,9 +90,9 @@ class Vetter:
         os.makedirs(indir)
         with open("{}/_config.txt".format(indir), 'w') as f:
             f.write(str(indir))
-        print("\n Download the text files required ... ")
-        print("\n Only the manifest text files (~325 M) will be downloaded and no TESS data.")
-        print("\n This step may take a while but luckily it only has to run once... \n")
+        logging.info("Download the text files required ... ")
+        logging.info("Only the manifest text files (~325 M) will be downloaded and no TESS data.")
+        logging.info("This step may take a while but luckily it only has to run once... \n")
         if not os.path.exists("{}".format(indir)):
             os.makedirs(indir)
         if not os.path.exists("{}/data".format(indir)):
@@ -118,12 +121,12 @@ class Vetter:
         candidate_df['TICID'] = candidate_df['TICID'].str.replace("TIC ", "")
         TIC_wanted = list(set(candidate_df['TICID']))
         nlc = len(TIC_wanted)
-        print("nlc length: {}".format(nlc))
-        print('{}/manifest.csv'.format(str(indir)))
+        logging.info("nlc length: {}".format(nlc))
+        logging.info('{}/manifest.csv'.format(str(indir)))
         if exists('{}/manifest.csv'.format(str(indir))):
-            print("Existing manifest file found, will skip previously processed LCs and append to end of manifest file")
+            logging.info("Existing manifest file found, will skip previously processed LCs and append to end of manifest file")
         else:
-            print("Creating new manifest file")
+            logging.info("Creating new manifest file")
             metadata_header = ['TICID', 'Marked Transits', 'Sectors', 'RA', 'DEC', 'Solar Rad', 'TMag', 'Teff',
                                'thissector', 'TOI', 'TCE', 'TCE link', 'EB', 'Systematics', 'Background Flux',
                                'Centroids Positions', 'Momentum Dumps', 'Aperture Size', 'In/out Flux', 'Keep',
@@ -143,15 +146,17 @@ class Vetter:
         @param transit_list: the list of transits for the given tic
         @return: the given tic
         """
+        logging.info("Runnint TESS Point")
         sectors_all, ra, dec = LATTEutils.tess_point(indir, tic)
         try:
             sectors = list(set(sectors_in) & set(sectors_all))
             if len(sectors) == 0:
-                print("The target was not observed in the sector(s) you stated ({}). \
+                logging.info("The target was not observed in the sector(s) you stated ({}). \
                         Therefore take all sectors that it was observed in: {}".format(sectors, sectors_all))
                 sectors = sectors_all
         except:
             sectors = sectors_all
+        logging.info("Downloading LATTE data")
         sectors = np.sort(sectors)
         if not ffi:
             alltime, allflux, allflux_err, all_md, alltimebinned, allfluxbinned, allx1, allx2, ally1, ally2, alltime12, allfbkg, start_sec, end_sec, in_sec, tessmag, teff, srad = LATTEutils.download_data(
@@ -172,9 +177,13 @@ class Vetter:
         last_time = alltime[len(alltime) - 1]
         num_of_transits = int(ceil(((last_time - t0) / period)))
         transit_lists = t0 + period * range(0, num_of_transits)
+        time_as_array = np.array(alltime)
+        transits_in_data = [time_as_array[(transit > time_as_array - 0.5) & (transit < time_as_array + 0.5)] for transit in transit_lists]
+        transit_lists = transit_lists[[len(transits_in_data_set) > 0 for transits_in_data_set in transits_in_data]]
         transit_lists = [transit_lists[x:x + 3] for x in range(0, len(transit_lists), 3)]
         for index, transit_list in enumerate(transit_lists):
             transit_results_dir = self.data_dir + "/" + str(index)
+            logging.info("Brewing LATTE data for transits at T0s: %s", str(transit_list))
             try:
                 if not ffi:
                     LATTEbrew.brew_LATTE(tic, indir, syspath, transit_list, simple, BLS, model, save, DV, sectors,
@@ -198,7 +207,7 @@ class Vetter:
                 traceback.print_exc()
                 # see if it made any plots - often it just fails on the TPs as they are very large
                 if exists("{}/{}/{}_fullLC_md.png".format(indir, tic, tic)):
-                    print("couldn't download TP but continue anyway")
+                    logging.warning("couldn't download TP but continue anyway")
                     tp_downloaded = False
                     shutil.move(vetter.latte_dir + "/" + tic, transit_results_dir)
                 else:
@@ -208,7 +217,7 @@ class Vetter:
             tp_downloaded = True
         else:
             tp_downloaded = False
-            print("code ran but no TP -- continue anyway")
+            logging.warn("code ran but no TP -- continue anyway")
         # -------------
         # check whether it's a TCE or a TOI
 
@@ -279,16 +288,9 @@ class Vetter:
             urls_exist = manifest_table['TICID']
             # get the transit time list
             period = df.loc[df['TICID'] == tic]['period'].iloc[0]
-            duration = df.loc[df['TICID'] == tic]['duration'].iloc[0]
             t0 = df.loc[df['TICID'] == tic]['t0'].iloc[0]
             transit_list = ast.literal_eval(((df.loc[df['TICID'] == tic]['transits']).values)[0])
-            transit_depth = df.loc[df['TICID'] == tic]['depth'].iloc[0]
             candidate_row = candidate.iloc[0]
-            if candidate_row["number"] is None or np.isnan(candidate_row["number"]):
-                lc_file = "/" + candidate_row["lc"]
-            else:
-                lc_file = "/" + str(candidate_row["number"]) + "/lc_" + str(candidate_row["curve"]) + ".csv"
-            lc_file = self.data_dir + lc_file
             try:
                 sectors_in = ast.literal_eval(str(((df.loc[df['TICID'] == tic]['sectors']).values)[0]))
                 if (type(sectors_in) == int) or (type(sectors_in) == float):
@@ -311,25 +313,18 @@ class Vetter:
                 ra = res['RA']
                 dec = res['DEC']
                 if res['TICID'] == -99:
-                    print('something went wrong with the LATTE results')
+                    logging.error('something went wrong with the LATTE results')
             except Exception as e:
                 traceback.print_exc()
                 try:
                     sectors_all, ra, dec = LATTEutils.tess_point(indir, tic)
                 except Exception as e1:
                     traceback.print_exc()
-            if self.validate:
-                try:
-                    result_dir, ra, dec = self.vetting_validation(cpus, indir, tic, sectors, lc_file, transit_depth, period,
-                                                                  t0, duration)
-                    shutil.move(result_dir, vetting_dir + "/triceratops")
-                except Exception as e:
-                    traceback.print_exc()
             if ra is not None and dec is not None:
                 result_dir = self.vetting_field_of_view(indir, tic, ra, dec, sectors)
                 shutil.move(result_dir, vetting_dir + "/tpfplot")
             else:
-                print("Can't generate tpfplot because RA and DEC are missing.")
+                logging.info("Can't generate tpfplot because RA and DEC are missing.")
             # TODO improve this condition to check whether tic, sectors and transits exist
         #     if not np.isin(tic, urls_exist):
         #         # make sure the file is opened as append only
@@ -360,144 +355,6 @@ class Vetter:
         #             writer.writerow(metadata_data)
         # return TIC_wanted
 
-    def vetting_validation(self, cpus, indir, tic, sectors, lc_file, transit_depth, period, t0, transit_duration):
-        """ Calculates probabilities of the signal being caused by any of the following astrophysical sources:
-        TP No unresolved companion. Transiting planet with Porb around target star. (i, Rp)
-        EB No unresolved companion. Eclipsing binary with Porb around target star. (i, qshort)
-        EBx2P No unresolved companion. Eclipsing binary with 2 × Porb around target star. (i, qshort)
-        PTP Unresolved bound companion. Transiting planet with Porb around primary star. (i, Rp, qlong)
-        PEB Unresolved bound companion. Eclipsing binary with Porb around primary star. (i, qshort, qlong)
-        PEBx2P Unresolved bound companion. Eclipsing binary with 2 × Porb around primary star. (i, qshort, qlong)
-        STP Unresolved bound companion. Transiting planet with Porb around secondary star. (i, Rp, qlong)
-        SEB Unresolved bound companion. Eclipsing binary with Porb around secondary star. (i, qshort, qlong)
-        SEBx2P Unresolved bound companion. Eclipsing binary with 2 × Porb around secondary star. (i, qshort, qlong)
-        DTP Unresolved background star. Transiting planet with Porb around target star. (i, Rp, simulated star)
-        DEB Unresolved background star. Eclipsing binary with Porb around target star. (i, qshort, simulated star)
-        DEBx2P Unresolved background star. Eclipsing binary with 2 × Porb around target star. (i, qshort, simulated star)
-        BTP Unresolved background star. Transiting planet with Porb around background star. (i, Rp, simulated star)
-        BEB Unresolved background star. Eclipsing binary with Porb around background star. (i, qshort, simulated star)
-        BEBx2P Unresolved background star. Eclipsing binary with 2 × Porb around background star. (i, qshort, simulated star)
-        NTP No unresolved companion. Transiting planet with Porb around nearby star. (i, Rp)
-        NEB No unresolved companion. Eclipsing binary with Porb around nearby star. (i, qshort)
-        NEBx2P No unresolved companion. Eclipsing binary with 2 × Porb around nearby star. (i, qshort)
-        FPP = 1 - (TP + PTP + DTP)
-        NFPP = NTP + NEB + NEBx2P
-        Giacalone & Dressing (2020) define validated planets as TOIs with NFPP < 10−3 and FPP < 0.015 (or FPP ≤ 0.01,
-        when rounding to the nearest percent)
-        @param cpus: number of cpus to be used
-        @param indir: root directory to store the results
-        @param tic: the tess object id for which the analysis will be run
-        @param sectors: the sectors of the tic
-        @param lc_file: the light curve source file
-        @param transit_depth: the depth of the transit signal (ppts)
-        @param period: the period of the transit signal /days)
-        @param t0: the t0 of the transit signal (days)
-        @param transit_duration: the duration of the transit signal (minutes)
-        """
-        save_dir = indir + "/" + str(tic) + "/triceratops_" + str(uuid.uuid4())
-        if os.path.exists(save_dir):
-            shutil.rmtree(save_dir, ignore_errors=True)
-        if not os.path.exists(save_dir):
-            os.makedirs(save_dir)
-        sectors = np.array(sectors)
-        duration = transit_duration / 60 / 24
-        target = tr.target(ID=tic, sectors=sectors)
-        # TODO allow user input apertures
-        tpfs = lightkurve.search_targetpixelfile("TIC " + str(tic), mission="TESS", cadence="short", sector=sectors.tolist())\
-            .download_all()
-        star = eleanor.multi_sectors(tic=tic, sectors=sectors, tesscut_size=31, post_dir=const.USER_HOME_ELEANOR_CACHE)
-        apertures = []
-        sector_num = 0
-        for s in star:
-            tpf_idx = [data.sector if data.sector == s.sector else -1 for data in tpfs.data]
-            tpf = tpfs[np.where(tpf_idx > np.zeros(len(tpf_idx)))[0][0]]
-            pipeline_mask = tpfs[np.where(tpf_idx > np.zeros(len(tpf_idx)))[0][0]].pipeline_mask
-            pipeline_mask = np.transpose(pipeline_mask)
-            pipeline_mask_triceratops = np.zeros((len(pipeline_mask[0]), len(pipeline_mask[:][0]), 2))
-            for i in range(0, len(pipeline_mask[0])):
-                for j in range(0, len(pipeline_mask[:][0])):
-                    pipeline_mask_triceratops[i, j] = [tpf.column + i, tpf.row + j]
-            pipeline_mask_triceratops[~pipeline_mask] = None
-            aperture = []
-            for i in range(0, len(pipeline_mask_triceratops[0])):
-                for j in range(0, len(pipeline_mask_triceratops[:][0])):
-                    if not np.isnan(pipeline_mask_triceratops[i, j]).any():
-                        aperture.append(pipeline_mask_triceratops[i, j])
-            apertures.append(aperture)
-            target.plot_field(save=True, fname=save_dir + "/field_S" + str(s.sector), sector=s.sector,
-                            ap_pixels=aperture)
-            sector_num = sector_num + 1
-        apertures = np.array(apertures)
-        depth = transit_depth / 1000
-        target.calc_depths(depth, apertures)
-        target.stars.to_csv(save_dir + "/stars.csv", index=False)
-        lc = pd.read_csv(lc_file, header=0)
-        time, flux, flux_err = lc["#time"].values, lc["flux"].values, lc["flux_err"].values
-        lc_len = len(time)
-        zeros_lc = np.zeros(lc_len)
-        lc = TessLightCurve(time=time, flux=flux, flux_err=flux_err, quality=zeros_lc)
-        lc.extra_columns = []
-        lc = lc.fold(period=period, epoch_time=t0, normalize_phase=True)
-        folded_plot_range = duration / 2 / period * 5
-        inner_folded_range_args = np.where((0 - folded_plot_range < lc.time.value) & (lc.time.value < 0 + folded_plot_range))
-        lc = lc[inner_folded_range_args]
-        lc.time = lc.time * period
-        sigma = np.mean(lc.flux_err)
-        input_n_times = [ValidatorInput(save_dir, copy.deepcopy(target), lc.time.value, lc.flux.value, sigma, period, depth,
-                                        apertures, value)
-                         for value in range(0, self.validation_runs)]
-        validator = Validator()
-        with Pool(processes=cpus) as pool:
-            validation_results = pool.map(validator.validate, input_n_times)
-        fpp_sum = 0
-        nfpp_sum = 0
-        probs_total_df = None
-        scenarios_num = len(validation_results[0][2])
-        star_num = np.zeros((5, scenarios_num))
-        u1 = np.zeros((5, scenarios_num))
-        u2 = np.zeros((5, scenarios_num))
-        fluxratio_EB = np.zeros((5, scenarios_num))
-        fluxratio_comp = np.zeros((5, scenarios_num))
-        target = input_n_times[0].target
-        target.star_num = np.zeros(scenarios_num)
-        target.u1 = np.zeros(scenarios_num)
-        target.u2 = np.zeros(scenarios_num)
-        target.fluxratio_EB = np.zeros(scenarios_num)
-        target.fluxratio_comp = np.zeros(scenarios_num)
-        i = 0
-        for fpp, nfpp, probs_df, star_num_arr, u1_arr, u2_arr, fluxratio_EB_arr, fluxratio_comp_arr in validation_results:
-            if probs_total_df is None:
-                probs_total_df = probs_df
-            else:
-                probs_total_df = pd.concat((probs_total_df, probs_df))
-            fpp_sum = fpp_sum + fpp
-            nfpp_sum = nfpp_sum + nfpp
-            star_num[i] = star_num_arr
-            u1[i] = u1_arr
-            u2[i] = u2_arr
-            fluxratio_EB[i] = fluxratio_EB_arr
-            fluxratio_comp[i] = fluxratio_comp_arr
-            i = i + 1
-        for i in range(0, scenarios_num):
-            target.star_num[i] = np.mean(star_num[:, i])
-            target.u1[i] = np.mean(u1[:, i])
-            target.u2[i] = np.mean(u2[:, i])
-            target.fluxratio_EB[i] = np.mean(fluxratio_EB[:, i])
-            target.fluxratio_comp[i] = np.mean(fluxratio_comp[:, i])
-        with open(save_dir + "/validation.csv", 'w') as the_file:
-            the_file.write("FPP,NFPP\n")
-            the_file.write(str(fpp_sum / self.validation_runs) + "," + str(nfpp_sum / self.validation_runs))
-        probs_total_df = probs_total_df.groupby("scenario", as_index=False).mean()
-        probs_total_df["scenario"] = pd.Categorical(probs_total_df["scenario"], ["TP", "EB", "EBx2P", "PTP", "PEB", "PEBx2P",
-                                                                         "STP", "SEB", "SEBx2P", "DTP", "DEB", "DEBx2P",
-                                                                         "BTP", "BEB", "BEBx2P", "NTP", "NEB", "NEBx2P"])
-        probs_total_df = probs_total_df.sort_values("scenario")
-        probs_total_df.to_csv(save_dir + "/validation_scenarios.csv", index=False)
-        target.probs = probs_total_df
-        # target.plot_fits(save=True, fname=save_dir + "/scenario_fits", time=lc.time.value, flux_0=lc.flux.value,
-        #                  flux_err_0=sigma)
-        return save_dir, star[0].coords[0], star[0].coords[1]
-
     @staticmethod
     def plot_fits(target, save_file, time: np.ndarray, flux_0: np.ndarray, sigma_0: float):
         """
@@ -628,6 +485,7 @@ class Vetter:
     def vetting_field_of_view(self, indir, tic, ra, dec, sectors):
         maglim = 6
         sectors_search = None if sectors is not None and len(sectors) == 0 else sectors
+        logging.info("Preparing target pixel files for field of view plots")
         tpf_source = lightkurve.search_targetpixelfile("TIC " + str(tic), sector=sectors, mission='TESS')
         if tpf_source is None or len(tpf_source) == 0:
             ra_str = str(ra)
@@ -636,6 +494,7 @@ class Vetter:
         for i in range(0, len(tpf_source)):
             tpf = tpf_source[i].download(cutout_size=(12, 12))
             pipeline = True
+            plt.close()
             fig = plt.figure(figsize=(6.93, 5.5))
             gs = gridspec.GridSpec(1, 3, height_ratios=[1], width_ratios=[1, 0.05, 0.01])
             gs.update(left=0.05, right=0.95, bottom=0.12, top=0.95, wspace=0.01, hspace=0.03)
@@ -645,19 +504,19 @@ class Vetter:
             nx, ny = np.shape(mean_tpf)
             norm = ImageNormalize(stretch=stretching.LogStretch())
             division = np.int(np.log10(np.nanmax(tpf.flux.value)))
-            splot = plt.imshow(np.nanmean(tpf.flux, axis=0) / 10 ** division, norm=norm, \
+            splot = plt.imshow(np.nanmean(tpf.flux, axis=0) / 10 ** division, norm=norm, cmap="viridis",\
                                extent=[tpf.column, tpf.column + ny, tpf.row, tpf.row + nx], origin='lower', zorder=0)
             # Pipeline aperture
             if pipeline:  #
                 aperture_mask = tpf.pipeline_mask
                 aperture = tpf._parse_aperture_mask(aperture_mask)
                 maskcolor = 'lightgray'
-                print("    --> Using pipeline aperture...")
+                logging.info("    --> Using pipeline aperture for sector %s...", tpf.sector)
             else:
                 aperture_mask = tpf.create_threshold_mask(threshold=10, reference_pixel='center')
                 aperture = tpf._parse_aperture_mask(aperture_mask)
                 maskcolor = 'lightgray'
-                print("    --> Using threshold aperture...")
+                logging.info("    --> Using threshold aperture for target %s...", tpf.sector)
 
             for i in range(aperture.shape[0]):
                 for j in range(aperture.shape[1]):
@@ -738,8 +597,8 @@ class Vetter:
     def show_candidates(self):
         self.candidates = pd.read_csv(self.object_dir + "/candidates.csv")
         self.candidates.index = np.arange(1, len(self.candidates) + 1)
-        print("Suggested candidates are:")
-        print(self.candidates.to_markdown(index=True))
+        logging.info("Suggested candidates are:")
+        logging.info(self.candidates.to_markdown(index=True))
         pass
 
     def demand_candidate_selection(self):
@@ -756,7 +615,7 @@ class Validator:
         super().__init__()
 
     def validate(self, input):
-        input.target.calc_depths(tdepth=input.depth, all_ap_pixels=input.apertures)
+        #input.target.calc_depths(tdepth=input.depth, all_ap_pixels=input.apertures)
         input.target.calc_probs(time=input.time, flux_0=input.flux, flux_err_0=input.sigma, P_orb=input.period)
         with open(input.save_dir + "/validation_" + str(input.run) + ".csv", 'w') as the_file:
             the_file.write("FPP,NFPP\n")
@@ -790,6 +649,23 @@ if __name__ == '__main__':
                     help="Whether to avoid running statistical validation")
     args = ap.parse_args()
     vetter = Vetter(args.object_dir, args.validate)
+    file_dir = vetter.object_dir + "/vetting.log"
+    if os.path.exists(file_dir):
+        os.remove(file_dir)
+    formatter = logging.Formatter('%(message)s')
+    logger = logging.getLogger()
+    while len(logger.handlers) > 0:
+        logger.handlers.pop()
+    logger.setLevel(logging.INFO)
+    handler = logging.StreamHandler(sys.stdout)
+    handler.setLevel(logging.INFO)
+    handler.setFormatter(formatter)
+    logger.addHandler(handler)
+    handler = logging.FileHandler(file_dir)
+    handler.setLevel(logging.INFO)
+    handler.setFormatter(formatter)
+    logger.addHandler(handler)
+    logging.info("Starting vetting")
     if args.candidate is None:
         user_properties = yaml.load(open(args.properties), yaml.SafeLoader)
         candidate = pd.DataFrame(columns=['id', 'transits', 'sectors', 'FFI'])
@@ -806,7 +682,7 @@ if __name__ == '__main__':
         candidate = candidates.iloc[[candidate_selection - 1]]
         candidate['number'] = [candidate_selection]
         vetter.data_dir = vetter.object_dir
-        print("Selected signal number " + str(candidate_selection))
+        logging.info("Selected signal number " + str(candidate_selection))
         if args.cpus is None:
             cpus = multiprocessing.cpu_count() - 1
         else:
